@@ -1,13 +1,10 @@
 """Test interplay of the various Avro helper classes"""
 from datetime import datetime
+from typing import List
 from unittest import TestCase
 
 from opaque_keys.edx.keys import CourseKey, UsageKey
 
-# Each new folder with signals must be manually imported in order for the signals to be cached
-#   and used in the unit tests. Using 'disable=reimported' with pylint will work,
-#   because we just use the cached signal list.
-from openedx_events.content_authoring import signals  # pylint: disable=unused-import
 from openedx_events.event_bus.avro.deserializer import AvroSignalDeserializer
 from openedx_events.event_bus.avro.serializer import AvroSignalSerializer
 from openedx_events.event_bus.avro.tests.test_utilities import (
@@ -20,9 +17,8 @@ from openedx_events.event_bus.avro.tests.test_utilities import (
     deserialize_bytes_to_event_data,
     serialize_event_data_to_bytes,
 )
-from openedx_events.learning import signals  # See note above; pylint: disable=reimported
 from openedx_events.tests.utils import FreezeSignalCacheMixin
-from openedx_events.tooling import OpenEdxPublicSignal
+from openedx_events.tooling import OpenEdxPublicSignal, load_all_signals
 
 # If a signal is explicitly not for use with the event bus, add it to this list
 #  and document why in the event's annotations
@@ -56,6 +52,7 @@ def generate_test_event_data_for_data_type(data_type):
         UsageKey: UsageKey.from_string(
             "block-v1:edx+DemoX+Demo_course+type@video+block@UaEBjyMjcLW65gaTXggB93WmvoxGAJa0JeHRrDThk",
         ),
+        List[int]: [1, 2, 3],
         datetime: datetime.now(),
     }
     for attribute in data_type.__attrs_attrs__:
@@ -63,6 +60,7 @@ def generate_test_event_data_for_data_type(data_type):
         if result is not None:
             data_dict.update({attribute.name: result})
         elif attribute.type in [dict, list]:
+            # pylint: disable-next=broad-exception-raised
             raise Exception("Unable to generate Avro schema for dict or array fields")
         else:
             data_dict.update({attribute.name: attribute.type(**generate_test_event_data_for_data_type(attribute.type))})
@@ -71,6 +69,13 @@ def generate_test_event_data_for_data_type(data_type):
 
 class TestAvro(FreezeSignalCacheMixin, TestCase):
     """Tests for end-to-end serialization and deserialization of events"""
+
+    @classmethod
+    def setUpClass(cls):
+        super().setUpClass()
+        # Ensure we can usefully call all_events()
+        load_all_signals()
+
     def test_all_events(self):
         for signal in OpenEdxPublicSignal.all_events():
             if signal.event_type in KNOWN_UNSERIALIZABLE_SIGNALS:
