@@ -1,7 +1,9 @@
 """
 Tooling necessary to use Open edX events.
 """
+import pkgutil
 import warnings
+from importlib import import_module
 from logging import getLogger
 
 from django.conf import settings
@@ -252,3 +254,28 @@ class OpenEdxPublicSignal(Signal):
         More information on send_robust in the Django official documentation.
         """
         self._allow_send_event_failure = True
+
+
+def _process_all_signals_modules(func):
+    """
+    Walk the package tree and apply func on all signals.py files.
+
+    Arguments:
+        func: A method that takes a module name as its parameter
+    """
+    root = import_module('openedx_events')
+    for m in pkgutil.walk_packages(root.__path__, root.__name__ + '.'):
+        module_name = m.name
+        if 'tests' in module_name.split('.') or '.test_' in module_name:
+            continue
+        if module_name.endswith('.signals'):
+            func(module_name)
+
+
+def load_all_signals():
+    """
+    Ensure OpenEdxPublicSignal.all_events() cache is fully populated.
+
+    Loads all non-test signals.py modules.
+    """
+    _process_all_signals_modules(import_module)
